pub struct DocRegistry { /* private fields */ }Expand description
holds every command doc and guide for the current program session.
Implementations
Sourceimpl DocRegistry
impl DocRegistry
Sourcepub fn register_command<K: Into<String>>(&mut self, key: K, doc: CommandDoc)
pub fn register_command<K: Into<String>>(&mut self, key: K, doc: CommandDoc)
attach metadata to a command path (dot-separated, "" for the main program).
Sourcepub fn register_guide<K, C>(&mut self, key: K, content: C)
pub fn register_guide<K, C>(&mut self, key: K, content: C)
add a free-form markdown guide that can be opened via guide <path>.
Sourcepub fn command(&self, key: &str) -> Option<&CommandDoc>
pub fn command(&self, key: &str) -> Option<&CommandDoc>
fetch docs for a command, if any.